@@ -15,7 +15,7 @@ from slapos.runner.utils import realpath, tail, isText
 
 
 class FileBrowser(object):
-  """This class contain all bases function for file browser"""
+  """This class contains all base functions for file browser"""
 
   def __init__(self, config):
     self.config = config
@@ -31,19 +31,19 @@ class FileBrowser(object):
     html = 'var gsdirs = [], gsfiles = [];'
 
     dir = urllib.unquote(dir)
-    # 'dir' is used below. XXX should not shadow a builtin name
+    # XXX-Marco 'dir' and 'all' should not shadow builtin names
     realdir = realpath(self.config, dir)
     if not realdir:
       raise NameError('Could not load directory %s: Permission denied' % dir)
 
     ldir = sorted(os.listdir(realdir), key=str.lower)
     for f in ldir:
-      if f.startswith('.') and not all: #do not display this file/folder
+      if f.startswith('.') and not all:  # do not display this file/folder
         continue
       ff = os.path.join(dir, f)
       realfile = os.path.join(realdir, f)
       mdate = datetime.datetime.fromtimestamp(os.path.getmtime(realfile)
-                    ).strftime("%Y-%d-%m %I:%M")
+                                              ).strftime("%Y-%d-%m %I:%M")
       md5sum = md5.md5(realfile).hexdigest()
       if not os.path.isdir(realfile):
         size = os.path.getsize(realfile)
@@ -53,25 +53,20 @@ class FileBrowser(object):
           ext = "unknow"
         else:
           ext = str.lower(ext)
-        html += 'gsfiles.push(new gsItem("1", "' + f + '", "' + \
-                  ff + '", "' + str(size) + '", "' + md5sum + \
-                  '", "' + ext + '", "' + mdate + '"));'
+        html += 'gsfiles.push(new gsItem("1", "%s", "%s", "%s", "%s", "%s", "%s"));' % (f, ff, size, md5sum, ext, mdate)
       else:
-        html += 'gsdirs.push(new gsItem("2", "' + f + '", "' + \
-                  ff + '", "0", "' + md5sum + '", "dir", "' + mdate + '"));'
+        html += 'gsdirs.push(new gsItem("2", "%s", "%s", "0", "%s", "dir", "%s"));' % (f, ff, md5sum, mdate)
     return html
 
-
   def makeDirectory(self, dir, filename):
     """Create a directory"""
     realdir = self._realdir(dir)
     folder = os.path.join(realdir, filename)
     if not os.path.exists(folder):
       os.mkdir(folder, 0744)
-      return '{result: \'1\'}'
+      return "{result: '1'}"
     else:
-      return '{result: \'0\'}'
-
+      return "{result: '0'}"
 
   def makeFile(self, dir, filename):
     """Create a file in a directory dir taken"""
@@ -79,36 +74,39 @@ class FileBrowser(object):
     fout = os.path.join(realdir, filename)
     if not os.path.exists(fout):
       open(fout, 'w')
-      return 'var responce = {result: \'1\'}'
+      return "var responce = {result: '1'}"
     else:
-      return '{result: \'0\'}'
+      return "{result: '0'}"
 
   def deleteItem(self, dir, files):
     """Delete a list of files or directories"""
+    # XXX-Marco do not shadow 'dir'
     realdir = self._realdir(dir)
     lfiles = urllib.unquote(files).split(',,,')
     try:
+      # XXX-Marco do not shadow 'file'
       for file in lfiles:
         file = os.path.join(realdir, file)
         if not os.path.exists(file):
-          continue #silent skip file....
+          continue  # silent skip file....
         details = file.split('/')
         last = details[-1]
         if last and last.startswith('.'):
-          continue #cannot delete this file/directory, to prevent security
+          continue  # cannot delete this file/directory, to prevent security
         if os.path.isdir(file):
           shutil.rmtree(file)
         else:
           os.unlink(file)
     except Exception as e:
       return str(e)
-    return '{result: \'1\'}'
+    return "{result: '1'}"
 
   def copyItem(self, dir, files, del_source=False):
     """Copy a list of files or directory to dir"""
     realdir = self._realdir(dir)
     lfiles = urllib.unquote(files).split(',,,')
     try:
+      # XXX-Marco do not shadow 'file'
       for file in lfiles:
         realfile = realpath(self.config, file)
         if not realfile:
@@ -117,7 +115,7 @@ class FileBrowser(object):
         details = realfile.split('/')
         dest = os.path.join(realdir, details[-1])
         if os.path.exists(dest):
-          raise NameError('NOT ALLOWED OPERATION : File or directory already exist')
+          raise NameError('NOT ALLOWED OPERATION : File or directory already exists')
         if os.path.isdir(realfile):
           shutil.copytree(realfile, dest)
           if del_source:
@@ -128,7 +126,7 @@ class FileBrowser(object):
             os.unlink(realfile)
     except Exception as e:
       return str(e)
-    return '{result: \'1\'}'
+    return "{result: '1'}"
 
   def rename(self, dir, filename, newfilename):
     """Rename file or directory to dir/filename"""
@@ -139,8 +137,8 @@ class FileBrowser(object):
     tofile = os.path.join(realdir, newfilename)
     if not os.path.exists(tofile):
       os.rename(realfile, tofile)
-      return '{result: \'1\'}'
-    raise NameError('NOT ALLOWED OPERATION : File or directory already exist')
+      return "{result: '1'}"
+    raise NameError('NOT ALLOWED OPERATION : File or directory already exists')
 
   def copyAsFile(self, dir, filename, newfilename):
     """Copy file or directory to dir/filename"""
@@ -148,21 +146,21 @@ class FileBrowser(object):
     fromfile = os.path.join(realdir, filename)
     tofile = os.path.join(realdir, newfilename)
     if not os.path.exists(fromfile):
-      raise NameError('NOT ALLOWED OPERATION : File or directory not exist')
+      raise NameError('NOT ALLOWED OPERATION : File or directory does not exist')
     if not os.path.exists(tofile):
       shutil.copy(fromfile, tofile)
-      return '{result: \'1\'}'
-    raise NameError('NOT ALLOWED OPERATION : File or directory already exist')
+      return "{result: '1'}"
+    raise NameError('NOT ALLOWED OPERATION : File or directory already exists')
 
   def uploadFile(self, dir, files):
-    """Upload a list of file in directory dir"""
+    """Upload a list of files in directory dir"""
     realdir = self._realdir(dir)
     for file in files:
       if files[file]:
         filename = werkzeug.secure_filename(files[file].filename)
         if not os.path.exists(os.path.join(dir, filename)):
           files[file].save(os.path.join(realdir, filename))
-    return '{result: \'1\'}'
+    return "{result: '1'}"
 
   def downloadFile(self, dir, filename):
     """Download file dir/filename"""
@@ -179,7 +177,7 @@ class FileBrowser(object):
     tozip = os.path.join(realdir, newfilename)
     fromzip = os.path.join(realdir, filename)
     if not os.path.exists(fromzip):
-      raise NameError('NOT ALLOWED OPERATION : File or directory not exist')
+      raise NameError('NOT ALLOWED OPERATION : File or directory does not exist')
     if not os.path.exists(tozip):
       zip = zipfile.ZipFile(tozip, 'w', zipfile.ZIP_DEFLATED)
       if os.path.isdir(fromzip):
@@ -191,8 +189,8 @@ class FileBrowser(object):
       else:
         zip.write(fromzip)
       zip.close()
-      return '{result: \'1\'}'
-    raise NameError('NOT ALLOWED OPERATION : File or directory already exist')
+      return "{result: '1'}"
+    raise NameError('NOT ALLOWED OPERATION : File or directory already exists')
 
   def unzipFile(self, dir, filename, newfilename):
     """Extract a zipped archive"""
@@ -200,7 +198,7 @@ class FileBrowser(object):
     target = os.path.join(realdir, newfilename)
     archive = os.path.join(realdir, filename)
     if not os.path.exists(archive):
-      raise NameError('NOT ALLOWED OPERATION : File or directory not exist')
+      raise NameError('NOT ALLOWED OPERATION : File or directory does not exist')
     if not os.path.exists(target):
       zip = zipfile.ZipFile(archive)
       #member = zip.namelist()
@@ -209,8 +207,8 @@ class FileBrowser(object):
       #  zip.extractall(target)
       #else:
       #  zip.extract(member[0], newfilename)
-      return '{result: \'1\'}'
-    raise NameError('NOT ALLOWED OPERATION : File or directory already exist')
+      return "{result: '1'}"
+    raise NameError('NOT ALLOWED OPERATION : File or directory already exists')
 
   def readFile(self, dir, filename, truncate=False):
     """Read file dir/filename and return content"""
@@ -221,6 +219,6 @@ class FileBrowser(object):
     if not isText(realfile):
       return "FILE ERROR: Cannot display binary file, please open a text file only!"
     if not truncate:
-      return open(realfile, 'r').read()
+      return open(realfile).read()
     else:
-      return tail(open(realfile, 'r'), 0)
+      return tail(open(realfile), 0)
